Test mode: Add X-Supersedes only if Supersedes would be set.
[usenet/yapfaq.git] / yapfaq.pl
index 846713e..5bc7919 100644 (file)
--- a/yapfaq.pl
+++ b/yapfaq.pl
@@ -1,6 +1,6 @@
 #! /usr/bin/perl -W
 #
 #! /usr/bin/perl -W
 #
# yapfaq Version 0.9 by Thomas Hochstein
 # (Original author: Marc Brockschmidt)
 #
 # This script posts any project described in its config-file. Most people
 # (Original author: Marc Brockschmidt)
 #
 # This script posts any project described in its config-file. Most people
@@ -12,7 +12,7 @@
 # It can be redistributed and/or modified under the same terms under 
 # which Perl itself is published.
 
 # It can be redistributed and/or modified under the same terms under 
 # which Perl itself is published.
 
-our $VERSION = "0.9";
+our $VERSION = "0.91";
 
 # Please do not change this setting!
 # You may override the default .rc file (.yapfaqrc) by using "-c .rc file"
 
 # Please do not change this setting!
 # You may override the default .rc file (.yapfaqrc) by using "-c .rc file"
@@ -300,7 +300,8 @@ sub postfaq {
     $$NG = $Options{'t'};
     $MID =~ s/@/-$Timestamp-test@/g;
     $$ExtraHeaders .= "\n" if $$ExtraHeaders;
     $$NG = $Options{'t'};
     $MID =~ s/@/-$Timestamp-test@/g;
     $$ExtraHeaders .= "\n" if $$ExtraHeaders;
-    $$ExtraHeaders .= "X-Supersedes: $$Supersedes\nX-yapfaq-Remark: This is only a test message.";
+    $$ExtraHeaders .= "X-Supersedes: $$Supersedes\n" if $$Supersedes;
+    $$ExtraHeaders .= "X-yapfaq-Remark: This is only a test message.";
     undef $$Supersedes;
   }
 
@@ -1,6 +1,6 @@
 #! /usr/bin/perl -W
 #
-# yapfaq Version 0.9 by Thomas Hochstein
+# yapfaq Version 0.91 by Thomas Hochstein
 # (Original author: Marc Brockschmidt)
 #
     undef $$Supersedes;
   }
 
This page took 0.010839 seconds and 4 git commands to generate.